## Origin of example data

The example mesh is a fruit fly neuron (an olfactory projection neuron of the
DA1 glomerulus) segmented from an EM image data set. It is part of the Janelia
hemibrain data set (see [here](https://neuprint.janelia.org)) [1].

### References
[1] Louis K. Scheffer et al., eLife. 2020. doi: 10.7554/eLife.57443
A connectome and analysis of the adult Drosophila central brain
